#
# This is the SPEC file for creating binary and source RPMs for the Dom0.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#

Name:		qubes-gui-daemon
Version:	4.3.3
Release:	1%{dist}
Summary:	The Qubes GUI virtualization

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org

Requires:	xorg-x11-server-Xorg
Requires:	service(graphical-login)
Requires:	libconfig
Requires:	python%{python3_pkgversion}-xcffib
Requires:	qubes-utils >= 4.2.10
Requires:	qubes-core-qrexec >= 4.1.5
Requires:	python%{python3_pkgversion}-qubesimgconverter >= 4.1.4
Requires:	socat
Requires:	group(qubes)
Requires:   (%{name}-selinux if selinux-policy)

BuildRequires:	python%{python3_pkgversion}-devel
BuildRequires:	python%{python3_pkgversion}-setuptools
BuildRequires:	pulseaudio-libs-devel
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(x11-xcb)
BuildRequires:	pkgconfig(xcb)
BuildRequires:	pkgconfig(xcb-aux)
BuildRequires:	pkgconfig(xcb-shm)
BuildRequires:	libXrandr-devel
BuildRequires:	libconfig-devel
BuildRequires:	libpng-devel
BuildRequires:	libnotify-devel
BuildRequires:	xen-devel
BuildRequires:	qubes-db-devel
BuildRequires:	help2man
BuildRequires:	gcc
BuildRequires:	qubes-core-libs-devel >= 1.6.1
BuildRequires:	qubes-core-libs
BuildRequires:	qubes-gui-common-devel >= 3.2.0
BuildRequires:	qubes-libvchan-xen-devel
BuildRequires:	qubes-utils-devel >= 4.2.10
BuildRequires:  selinux-policy-devel

Source0: %{name}-%{version}.tar.gz

%description
The Qubes GUI virtualization infrastructure that needs to be installed in GuiVM.

%package -n qubes-gui-dom0
Summary:    Dom0 part of Qubes GUI
# For now require also gui-daemon in dom0, when dropping GUI in dom0, this
# dependency should be dropped
Requires:   qubes-gui-daemon
# Pull also audio packages for easier upgrade
Requires:   qubes-audio-daemon
Requires:   qubes-audio-dom0
Requires:	qubes-core-dom0 >= 4.1.1
# for policy.EvalSimple service
Requires:	qubes-core-qrexec-dom0 >= 4.1.14
Requires:   python%{python3_pkgversion}-setuptools

%description -n qubes-gui-dom0
Dom0 files for Qubes GUI virtualization. This include core-admin extension,
policy files etc.

%package -n qubes-audio-daemon
Summary:	The Qubes AUDIO virtualization
Requires:	pulseaudio-libs
%if 0%{?fedora} >= 35
Requires:	pulseaudio-daemon
%else
Requires:	pulseaudio
%endif
Requires:	libconfig
Requires:   qubes-utils >= 3.1.0
Requires:   python%{python3_pkgversion}-pydbus

%description -n qubes-audio-daemon
The Qubes AUDIO virtualization infrastructure that needs to be installed in AudioVM.

%package -n qubes-audio-dom0
Summary:    Dom0 part of Qubes AUDIO
Requires:	qubes-core-dom0 >= 1.3.14
Requires:   python%{python3_pkgversion}-setuptools

%description -n qubes-audio-dom0
Dom0 files for Qubes AUDIO virtualization. This include core-admin extension,
policy files etc.

%package selinux

BuildRequires: selinux-policy
%{?selinux_requires}

Summary: SELinux policy for qubes-gui-daemon
License: GPLv2+

%description selinux
SELinux policy for qubes-gui-daemon.  You need this package to run qubes-guid
on a system where SELinux is in enforcing mode.

%post selinux
%selinux_modules_install %{_datadir}/selinux/packages/qubes-gui-daemon.pp || :

%postun selinux
if [ "$1" -eq 0 ]; then
    %selinux_modules_uninstall %{_datadir}/selinux/packages/qubes-gui-daemon.pp
fi || :

%posttrans selinux
%selinux_relabel_post
exit 0

%prep
%setup -q

%build
%{?set_build_flags}
make clean
make all all-selinux BACKEND_VMM=xen

%py3_build

%pre

%install
rm -rf $RPM_BUILD_ROOT
%make_install
make install-selinux DESTDIR=$RPM_BUILD_ROOT
%py3_install

%triggerin -- xorg-x11-server-Xorg
ln -sf /usr/bin/X-wrapper-qubes /usr/bin/X

%postun
if [ "$1" = 0 ] ; then
	# no more packages left
    ln -sf /usr/bin/Xorg /usr/bin/X
fi

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}

%files
%defattr(-,root,root,-)
%attr(4750,root,qubes) /usr/bin/qubes-guid
%{_mandir}/man1/qubes-guid.1.gz
/usr/bin/X-wrapper-qubes
%{_libdir}/qubes-gui-daemon/shmoverride.so
%config(noreplace) %{_sysconfdir}/qubes/guid.conf
/etc/xdg/autostart/qubes-screen-layout-watches.desktop
/etc/xdg/autostart/qubes-icon-receiver.desktop
/etc/X11/xinit/xinitrc.d/qubes-localgroup.sh
/usr/libexec/qubes/watch-screen-layout-changes
/usr/lib/qubes/icon-receiver
%config %{_sysconfdir}/qubes-rpc/qubes.WindowIconUpdater
%config %{_sysconfdir}/qubes/rpc-config/qubes.WindowIconUpdater

%files -n qubes-audio-daemon
/usr/bin/pacat-simple-vchan

%files -n qubes-gui-dom0
%config(noreplace) %{_sysconfdir}/qubes/policy.d/90-default-gui-daemon.policy

%files -n qubes-audio-dom0
%{python3_sitelib}/qubesguidaemon-*.egg-info
%{python3_sitelib}/qubesguidaemon

%files selinux
%{_datadir}/selinux/packages/qubes-gui-daemon.pp

%changelog
* Mon Aug 12 2024 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-gui-daemon.git

* Mon Aug 12 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9966538
- version 4.3.3

* Mon Jul 22 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c6acd17
- Use QubesDB to authorize usage of mic and retrieve its status

* Fri Jul 05 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 28dc3e1
- version 4.3.2

* Fri Jul 05 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - cac038a
- Update lint job

* Fri Jul 05 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 660ac1b
- Reformat according to python-black

* Sat Jun 22 2024 Euwiiwueir <euweuwi2@onionmail.info> - 51399c3
- qubes-guid: add window_background_color setting

* Sat Jun 22 2024 Euwiiwueir <euweuwi2@onionmail.info> - 7e85df2
- Factor out a function to parse color from string

* Mon Jun 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 122f9b4
- version 4.3.1

* Sat Jun 15 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 68f8855
- version 4.3.0

* Fri Jun 14 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e585798
- Add basic SELinux policy

* Wed May 08 2024 Piotr Bartman <prbartman@invisiblethingslab.com> - 2062be5
- q-dev: better description of mic

* Wed May 08 2024 Piotr Bartman <prbartman@invisiblethingslab.com> - cd97c56
- q-dev: fix device protocol

* Wed May 08 2024 Piotr Bartman <prbartman@invisiblethingslab.com> - 77609d8
- q-dev: device protocol

* Wed May 08 2024 Piotr Bartman <prbartman@invisiblethingslab.com> - cef05f9
- q-dev: set Microphone Interface

* Wed May 08 2024 Piotr Bartman <prbartman@invisiblethingslab.com> - 157b079
- q-dev: change `devclass` to be consistent with qubes-core-admin

* Wed May 08 2024 Piotr Bartman <prbartman@invisiblethingslab.com> - e3e097e
- q-dev: reformat file + typos

* Sun Apr 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e5414b7
- version 4.2.7

* Fri Apr 26 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c4b92a0
- pacat-simple-vchan: improve cleanup

* Fri Apr 05 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6583783
- version 4.2.6

* Mon Mar 25 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 65cd1d7
- pacat-simple-vchan: reconnect on vchan eof

* Sat Feb 24 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0be59e2
- pulse: make tlength parameter configurable, reduce fragsize

* Sat Feb 24 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 68a5dba
- pulse: add opt-in debug logging

* Thu Feb 22 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8874142
- pulse: add timestamps to log output

* Mon Feb 05 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9029d0e
- version 4.2.5

* Mon Feb 05 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b99da5a
- shmoverride: fix parameters order

* Thu Jan 25 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 9795a4e
- Always block on vchan I/O by default

* Thu Jan 11 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 599e593
- version 4.2.4

* Wed Jan 03 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - d1826fb
- Do not crash if the work area is invalid

* Mon Sep 18 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 9584e3f
- Allow periods in qube names

* Fri Sep 15 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1ba8051
- Revert "Allow periods in qube names"

* Sun Aug 20 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - a8f61fe
- Allow periods in qube names

* Mon Aug 14 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 4bf3a93
- Clean up do_shm_update

* Thu Apr 27 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - adadf48
- version 4.2.3

* Sat Apr 15 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 0a255d9
- Allow selecting blocking or non-blocking I/O

* Sat Apr 15 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - e54de11
- Do not cork a playback stream with nonempty buffers

* Thu Apr 13 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 0fbcb05
- Drain playback stream before corking it

* Sat Mar 18 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 811a31a
- Ensure notifications conform to header-body format

* Sat Mar 18 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 5bc9a32
- Do not send MSG_DESTROY to agents that aren't expecting it

* Sat Mar 18 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - bd38763
- Avoid hard-coding protocol versions

* Sat Mar 18 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - ce984fb
- ACK all grant mappings

* Fri Feb 03 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d815f91
- version 4.2.2

* Thu Feb 02 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f10c50e
- Use new qrexec policy format

* Thu Feb 02 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e413294
- rpm: fix files ownership on install

* Thu Jan 12 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 180f8de
- Strictly validate message lengths

* Thu Jan 12 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - be2d345
- Earlier validation of MSG_WINDOW_DUMP sizes

* Thu Jan 12 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 5de8e14
- Do not use VERIFY with partially-read messages

* Thu Jan 12 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 9e0b82d
- Do not read a message unless a header is ready

* Mon Jan 09 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 5d4a4d2
- Fix a typo in a comment

* Mon Jan 09 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - e3dac04
- do_shm_update: Negative width or height is an error

* Mon Jan 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b40c15a
- version 4.2.1

